#!/bin/bash
# Adapt ChrisGagnon's Jenkins scripts for DEP 8
set -e

if [ -z $1 ]; then
    echo 'you must specify the test to run, example: lrt.test_random_gestures'
    exit 1
fi
TEST_NAME=$1

# ChrisGagnon has secured special CRASH_IDs for the defined tests via
# bdmurray (NOTE that each starts with 'deadbeef').
# XXX alesage 20141112
# NOTE that that $CRASH_ID needs to appear in whoopsie.conf;
# suggestions for implementation in PROVISIONING_IN_CI_README.sh.
if [ $TEST_NAME == "lrt.test_random_gestures" ]; then
CRASH_ID=deadbeef2b73679bb94cc77874f81c4822482114dd8bf912741713eb15bf61533b5d8176f0d870f758cc6f241445ffd3359debe1616c832a8ab3b7626d9ed369
fi
# NOTE: re-enable these if and when each test below is brought online.
#if [ $TEST_NAME == "lrt.test_switch" ]; then
#CRASH_ID=deadbeef17372a2ac165df1ed82002d7cbeeb0aad6adaa39a7a65fc29cb6c724878e3009de7787c88de01911bf874932edb8d11d7debc7506331e8fb5c99a9e3
#fi
#if [ $test_to_run == &quot;lrt.test_random&quot; ]; then
#CRASH_ID=deadbeef2b73679bb94cc77874f81c4822482114dd8bf912741713eb15bf61533b5d8176f0d870f758cc6f241445ffd3359debe1616c832a8ab3b7626d9ed369
#fi
#if [ $test_to_run == &quot;lrt.test_switch&quot; ]; then
#CRASH_ID=deadbeef17372a2ac165df1ed82002d7cbeeb0aad6adaa39a7a65fc29cb6c724878e3009de7787c88de01911bf874932edb8d11d7debc7506331e8fb5c99a9e3
#fi
#if [ $test_to_run  == &quot;lrt.test_ap_core_apps&quot; ]; then
#CRASH_ID=deadbeef6ad56ff7b1050f384439a7900acdd7dcce06e81cb051c3417320a19baa4f1769d9fe20e9b01ac5b970d7b1a339526d6edf572d9e2eb7fa3c3232d13c6
#fi
#if [ $test_to_run  == &quot;lrt.test_ap_system&quot; ]; then
#CRASH_ID=deadbeef34567890123de0f384439a7900acdd7dcce06e81cb051c3417320a19baa4f1769d9fe20e9b01cd5b970d7b1e339897d6fdf572d9e2eb7fa3c3232d14
#fi
#if [ $test_to_run  == &quot;lrt.test_power&quot; ]; then
#CRASH_ID=deadbeefad56ff7b1050f384439a7900acdd7dcce06e81cb051c3417320a19baa4f1769d9fe20e9b01ac5b970d7b1a339526d6edf572d9e2eb7fa3c3232d1376
#fi

python3 -m subunit.run $TEST_NAME > ~/result.subunit || true
sudo chmod a+rw ~/result.subunit

# Prepare to whoopsie.
# disable flight mode (a random gesture may have enable)
sudo /usr/share/urfkill/scripts/flight-mode 0
# wait for wifi a bit
sleep 10
# enable wifi, the test sometimes disables it
ping -c2 launchpad.net || nmcli nm wifi on
list_crashes=$(sudo ls /var/crash)
if [ -z "$list_crashes" ]; then
    echo no crash files found
    exit 0
fi
# wait for crash file to be ready
ls /var/crash | grep crash | while read line; do
    while [ $(stat -c "%a %n" /var/crash/$line | cut -d ' ' -f1) -le 0 ] ; do
        sleep 5
        echo "waiting for crash file to become ready" to upload
    done
done
# upload to errors.ubuntu.com
# ChrisGagnon says "this fails a lot"
sudo /usr/share/apport/whoopsie-upload-all || true
sudo tail /var/log/upstart/whoopsie.log || true

# gather our artifacts
ls=$(ls /var/crash) 
echo $ls > $ADT_ARTIFACTS/crash_files.log
cp -R /var/crash/ $ADT_ARTIFACTS/crash
cp -R /var/log/system-image $ADT_ARTIFACTS/system-image
cp /home/phablet/result.subunit $ADT_ARTIFACTS/result.subunit
cp /var/log/syslog $ADT_ARTIFACTS/syslog
cp /var/log/kern.log $ADT_ARTIFACTS/kern.log || true
cp -R /home/phablet/.cache/upstart $ADT_ARTIFACTS/upstart 
echo "exiting"

exit 4
